@@ -1,5 +1,5 @@
 # encoding: utf-8
-# Copyright (c) 2011 Volvox Development Team
+# Copyright (c) 2012 Volvox Development Team
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -21,18 +21,26 @@
 #
 # Author: Konstantin Lepa <konstantin.lepa@gmail.com>
 
+"""
+Example:
+    import pyctpp2
+
+    engine = pyctpp2.Engine()
+    engine.path = [ '/www/templates' ] # set paths for searching templates
+
+    template = engine.parse_text('<TMPL_var array[0].key>')
+    result = template.render({'foo': 'bar',
+                             'array': [{'key': 'first'}, {'key': 'second'}]})
+
+
+See `pydoc pyctpp2.Engine` and `pydoc pyctpp2.Template` for more information.
+
+"""
+
 import re
 
-try:
-    from _pyctpp2 import Engine, Template
-except ImportError:
-    pass
-
-__version__ = '0.11.2'
-__version_info__ = __version__.split('.')
-
-CTPP2_VERSION = (2, 7, 0)
-
+from ._pyctpp2 import Engine, Template
+from .version import *
 
 STRING_RE = r"""(?: '(?: [^'\\] | \\. )*' | "(?: [^"\\] | \\.)*")"""
 
